#!/usr/bin/env python

#--------------------------------------------------------------------------------------
## Copyright 2010 Alexey Petrov
##
## Licensed under the Apache License, Version 2.0 (the "License");
## you may not use this file except in compliance with the License.
## You may obtain a copy of the License at
##
##     http://www.apache.org/licenses/LICENSE-2.0
##
## Unless required by applicable law or agreed to in writing, software
## distributed under the License is distributed on an "AS IS" BASIS,
## WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
## See the License for the specific language governing permissions and
## limitations under the License.
##
## See http://sourceforge.net/apps/mediawiki/balloon-foam
##
## Author : Alexey Petrov
##


#--------------------------------------------------------------------------------------
"""
This script is responsible for cluster environment setup for the given Amazon EC2 reservation
"""


#--------------------------------------------------------------------------------------
import balloon.common as common
from balloon.common import print_d, print_e, sh_command, Timer

from balloon import amazon
from balloon.amazon import ec2


#--------------------------------------------------------------------------------------
# Defining utility command-line interface

an_usage_description = "%prog --case-dir='./damBreak'"
an_usage_description += ec2.use.add_usage_description()
an_usage_description += amazon.add_usage_description()
an_usage_description += common.add_usage_description()

from optparse import IndentedHelpFormatter
a_help_formatter = IndentedHelpFormatter( width = 127 )

from optparse import OptionParser
an_option_parser = OptionParser( usage = an_usage_description, version="%prog 0.1", formatter = a_help_formatter )

an_option_parser.add_option( "--case-dir",
                             metavar = "< location of the source OpenFOAM case dir >",
                             action = "store",
                             dest = "case_dir",
                             default = None )
an_option_parser.add_option( "--output-suffix",
                             metavar = "< folder suffix for the output results >",
                             action = "store",
                             dest = "output_suffix",
                             default = '.out' )
ec2.use.add_parser_options( an_option_parser )
amazon.add_parser_options( an_option_parser )
common.add_parser_options( an_option_parser )
  
 
#--------------------------------------------------------------------------------------
# Extracting and verifying command-line arguments

an_options, an_args = an_option_parser.parse_args()

an_enable_debug = common.extract_options( an_options )
AWS_ACCESS_KEY_ID, AWS_SECRET_ACCESS_KEY = amazon.extract_options( an_options )
an_image_location, a_reservation_id, an_identity_file, a_host_port, a_login_name = ec2.use.extract_options( an_options )

if an_options.case_dir == None :
    an_option_parser.error( "Use '--case-dir' option to define folder containing solver case\n" )
    pass

import os
a_case_dir = os.path.abspath( an_options.case_dir )
if not os.path.isdir( a_case_dir ) :
    an_option_parser.error( "--case-dir='%s' should be a folder\n" % a_case_dir )
    pass

an_output_suffix = an_options.output_suffix


print_d( "\n--------------------------- Canonical substitution ------------------------\n" )
import sys
an_engine = sys.argv[ 0 ]

a_call = "%s --case-dir='%s' %s" % ( an_engine, a_case_dir, ec2.use.compose_call( an_options ) )
print_d( a_call + '\n' )


print_d( "\n----------------------- Running actual functionality ----------------------\n" )
a_spent_time = Timer()

an_ec2_conn = ec2.region_connect( an_image_location, AWS_ACCESS_KEY_ID, AWS_SECRET_ACCESS_KEY )
a_reservation = ec2.use.get_reservation( an_ec2_conn, a_reservation_id )

a_password = "" # No password
an_identity_file = an_identity_file
a_host_port = a_host_port
a_login_name = a_login_name

from balloon.common import ssh
an_instance2ssh = {}

a_security_credentials = "--aws-access-key-id=%s --aws-secret-access-key=%s" % ( AWS_ACCESS_KEY_ID, AWS_SECRET_ACCESS_KEY )
a_master_node = an_instance = a_reservation.instances[ 0 ]
a_host_name = an_instance.public_dns_name


print_d( "\n--------------------- Uploading case data to S3 ---------------------------\n"  )
a_case_name = os.path.basename( a_case_dir )
an_input_study = sh_command( 'amazon_upload_start.py %s %s | amazon_upload_resume.py %s' %
                             ( a_case_dir, a_security_credentials, a_security_credentials ) )[ 0 ][ : -1 ]
print_d( "an_input_study = '%s'\n" % an_input_study )


print_d( "\n------------------ Installing balloon to master node ----------------------\n"  )
print_d( 'ssh -o "StrictHostKeyChecking no" -i %s -p %d %s@%s\n' % ( an_identity_file, a_host_port, a_login_name, a_host_name ) )
a_ssh_client = ssh.connect( a_password, an_identity_file, a_host_port, a_login_name, a_host_name, 'env' )
an_instance2ssh[ an_instance ] = a_ssh_client

# sh_command( "./balloon_deploy.py --identity-file=%s --host-port=%s --login-name=%s --host-name=%s" %
#             ( an_identity_file, a_host_port, a_login_name, a_host_name ) )
ssh.command( a_ssh_client, "sudo easy_install balloon" )


print_d( "\n------------- Downloading case data from S3 to the master node ------------\n"  )
a_working_dir = ssh.command( a_ssh_client, 'python -c "import os, os.path, tempfile; print tempfile.mkdtemp()"' )[ 0 ][ : -1 ]
print_d( "a_working_dir = '%s'\n" % a_working_dir )

ssh.command( a_ssh_client, "amazon_download.py --study-name=%s --output-dir=%s %s" % ( an_input_study, a_working_dir, a_security_credentials ) )

print_d( "\n--- Sharing the solver case folder for all the cluster nodes through NFS --\n" )
ssh.command( a_ssh_client, "sudo sh -c 'echo %s *\(rw,no_root_squash,sync,subtree_check\) >> /etc/exports'" % ( a_working_dir ) )
ssh.command( a_ssh_client, "sudo exportfs -a" ) # make changes effective on the running NFS server

for an_instance in a_reservation.instances[ 1 : ] :
    a_host_name = an_instance.public_dns_name
    print_d( 'ssh -o "StrictHostKeyChecking no" -i %s -p %d %s@%s\n' % ( an_identity_file, a_host_port, a_login_name, a_host_name ) )

    a_ssh_client = ssh.connect( a_password, an_identity_file, a_host_port, a_login_name, a_host_name )
    ssh.command( a_ssh_client, "mkdir -p %s" % ( a_working_dir ) )
    ssh.command( a_ssh_client, "sudo mount %s:%s %s" % ( a_master_node.private_ip_address, a_working_dir, a_working_dir ) )

    an_instance2ssh[ an_instance ] = a_ssh_client
    pass


print_d( "\n----------------------- Running of the solver case ------------------------\n" )
a_ssh_client = an_instance2ssh[ a_master_node ]
a_tagret_dir = os.path.join( a_working_dir, a_case_name )
ssh.command( a_ssh_client, "source ~/.profile && %s/Allrun %d" % ( a_tagret_dir, len( a_reservation.instances ) ) ) # running the solver case


print_d( "\n-----------------------  Uploading results to S3 --------------------------\n" )
an_output_study = ssh.command( a_ssh_client, 'amazon_upload_start.py %s %s | amazon_upload_resume.py %s' %
                               ( a_tagret_dir, a_security_credentials, a_security_credentials ) )[ 0 ][ : -1 ]
print_d( "an_output_study = '%s'\n" % an_output_study )


print_d( "\n----------------------  Downloading results from S3 -----------------------\n" )
import tempfile
an_output_dir = tempfile.mkdtemp()
sh_command( "amazon_download.py --study-name=%s --output-dir=%s %s" % ( an_output_study, an_output_dir, a_security_credentials ) )[ 0 ][ : -1 ]
print_d( "an_output_dir = '%s'\n" % an_output_dir )

import shutil
a_tagret_dir = a_case_dir + an_output_suffix
print_d( "a_tagret_dir = '%s'\n" % a_tagret_dir )

shutil.rmtree( a_tagret_dir, True )
shutil.move( os.path.join( an_output_dir, a_case_name ), a_tagret_dir )
shutil.rmtree( an_output_dir, True )

# To speed-up the script execution; user can remove all these studies afterwards by the following command
#   amazon_ls.py | xargs amazon_rm_study.py
# sh_command( a_ssh_client, "amazon_rm_study.py %s %s" % ( an_input_study, a_security_credentials ) )
# sh_command( a_ssh_client, "amazon_rm_study.py %s %s" % ( an_output_study, a_security_credentials ) )

[ a_ssh_client.close() for a_ssh_client in an_instance2ssh.values() ]

print_d( "a_spent_time = %s, sec\n" % a_spent_time )


print_d( "\n------------------ Printing succussive pipeline arguments -----------------\n" )
ec2.use.print_options( *ec2.use.unpack( an_options ) )


print_d( "\n--------------------------- Canonical substitution ------------------------\n" )
print_d( a_call + '\n' )


print_d( "\n-------------------------------------- OK ---------------------------------\n" )



#!/usr/bin/env python

#------------------------------------------------------------------------------------------
## Copyright 2010 Alexey Petrov
##
## Licensed under the Apache License, Version 2.0 (the "License");
## you may not use this file except in compliance with the License.
## You may obtain a copy of the License at
##
##     http://www.apache.org/licenses/LICENSE-2.0
##
## Unless required by applicable law or agreed to in writing, software
## distributed under the License is distributed on an "AS IS" BASIS,
## WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
## See the License for the specific language governing permissions and
## limitations under the License.
##
## See http://sourceforge.net/apps/mediawiki/balloon-foam
##
## Author : Alexey Petrov
##


#------------------------------------------------------------------------------------------
"""
Deletes all running Amazon EC2 reservations and release all resources incorporated by them
"""

#------------------------------------------------------------------------------------------
import boto
import boto.ec2

import balloon.common as common
from balloon.common import print_d, print_i, print_e, sh_command, Timer, WorkerPool

import balloon.amazon as amazon


#------------------------------------------------------------------------------------------
# Defining utility command-line interface
an_usage_description = "%prog"
an_usage_description += common.add_usage_description()
an_usage_description += amazon.add_usage_description()

from optparse import IndentedHelpFormatter
a_help_formatter = IndentedHelpFormatter( width = 127 )

from optparse import OptionParser
a_option_parser = OptionParser( usage = an_usage_description, version="%prog 0.1", formatter = a_help_formatter )

# Definition of the command line arguments
common.add_parser_options( a_option_parser )
amazon.add_parser_options( a_option_parser )


#------------------------------------------------------------------------------------------
# Extracting and verifying command-line arguments

an_options, an_args = a_option_parser.parse_args()

common.extract_options( an_options )

AWS_ACCESS_KEY_ID, AWS_SECRET_ACCESS_KEY = amazon.extract_options( an_options )


#------------------------------------------------------------------------------------------
def stop_instance( the_instance ) :
    a_status = the_instance.update()
    if a_status != 'terminated' :
        print "%s : %s : '%s'" % ( the_instance, a_status, the_instance.dns_name )
        the_instance.stop()

        pass

    pass


#------------------------------------------------------------------------------------------
def delete_key_pair( the_key_pair ) :
    print the_key_pair.name

    # an_ec2_conn.delete_key_pair( the_key_pair ) # Does not work (bug)
    the_key_pair.delete()

    import os.path
    a_key_pair_dir = os.path.expanduser( "~/.ssh")
    a_key_pair_file = os.path.join( a_key_pair_dir, the_key_pair.name ) + os.path.extsep + "pem"

    if os.path.isfile( a_key_pair_file ) :
        os.remove( a_key_pair_file )
        pass
    
    pass


#------------------------------------------------------------------------------------------
def delete_security_group( the_ec2_conn, the_security_group ) :
    if the_security_group.name != 'default' :
        print the_security_group.name
        the_ec2_conn.delete_security_group( the_security_group.name )
        
        pass
    pass


#------------------------------------------------------------------------------------------
a_worker_pool = WorkerPool( 8 )

for a_region in boto.ec2.regions( aws_access_key_id = AWS_ACCESS_KEY_ID, aws_secret_access_key = AWS_SECRET_ACCESS_KEY ) :
    an_ec2_conn = a_region.connect()
    print a_region

    print_d( "\n--------------------------- Delete EC2 instances --------------------------\n" )
    for a_reservation in an_ec2_conn.get_all_instances() :
        for an_instance in a_reservation.instances :
            # a_worker_pool.charge( stop_instance, ( an_instance ) )
            stop_instance( an_instance )
            pass
        pass
    print
    a_worker_pool.join()

    print_d( "\n--------------------------- Delete EC2 key pairs --------------------------\n" )
    for a_key_pair in an_ec2_conn.get_all_key_pairs() :
        # a_worker_pool.charge( delete_key_pair, ( a_key_pair ) )
        delete_key_pair( a_key_pair )
        pass
    print


    print_d( "\n------------------------ Delete EC2 security groups -----------------------\n" )
    for a_security_group in an_ec2_conn.get_all_security_groups() :
        # a_worker_pool.charge( delete_security_group, ( an_ec2_conn, a_security_group ) )
        delete_security_group( an_ec2_conn, a_security_group )
        pass
    print

    a_worker_pool.join()
    pass


a_worker_pool.shutdown()
a_worker_pool.join()


print_d( "\n-------------------------------------- OK ---------------------------------\n" )





#!/usr/bin/env python

#--------------------------------------------------------------------------------------
## Copyright 2010 Alexey Petrov
##
## Licensed under the Apache License, Version 2.0 (the "License");
## you may not use this file except in compliance with the License.
## You may obtain a copy of the License at
##
##     http://www.apache.org/licenses/LICENSE-2.0
##
## Unless required by applicable law or agreed to in writing, software
## distributed under the License is distributed on an "AS IS" BASIS,
## WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
## See the License for the specific language governing permissions and
## limitations under the License.
##
## See http://sourceforge.net/apps/mediawiki/balloon-foam
##
## Author : Alexey Petrov
##


#--------------------------------------------------------------------------------------
"""
This script is responsible for cluster environment setup for the given Amazon EC2 reservation
"""


#--------------------------------------------------------------------------------------
import balloon.common as common
from balloon.common import print_d, print_e, sh_command, Timer

from balloon import amazon
from balloon.amazon import ec2


#--------------------------------------------------------------------------------------
# Defining utility command-line interface

an_usage_description = "%prog"
an_usage_description += ec2.use.add_usage_description()
an_usage_description += amazon.add_usage_description()
an_usage_description += common.add_usage_description()

from optparse import IndentedHelpFormatter
a_help_formatter = IndentedHelpFormatter( width = 127 )

from optparse import OptionParser
an_option_parser = OptionParser( usage = an_usage_description, version="%prog 0.1", formatter = a_help_formatter )

ec2.use.add_parser_options( an_option_parser )
amazon.add_parser_options( an_option_parser )
common.add_parser_options( an_option_parser )
  
 
#--------------------------------------------------------------------------------------
# Extracting and verifying command-line arguments

an_options, an_args = an_option_parser.parse_args()

an_enable_debug = common.extract_options( an_options )
AWS_ACCESS_KEY_ID, AWS_SECRET_ACCESS_KEY = amazon.extract_options( an_options )
an_image_location, a_reservation_id, an_identity_file, a_host_port, a_login_name = ec2.use.extract_options( an_options )


print_d( "\n--------------------------- Canonical substitution ------------------------\n" )
import sys
an_engine = sys.argv[ 0 ]

a_call = "%s %s" % ( an_engine, ec2.use.compose_call( an_options ) )
print_d( a_call + '\n' )


print_d( "\n----------------------- Running actual functionality ----------------------\n" )
a_spent_time = Timer()

an_ec2_conn = ec2.region_connect( an_image_location, AWS_ACCESS_KEY_ID, AWS_SECRET_ACCESS_KEY )
a_reservation = ec2.use.get_reservation( an_ec2_conn, a_reservation_id )
a_security_group = ec2.use.get_security_group( an_ec2_conn, a_reservation )

a_password = "" # No password
an_identity_file = an_identity_file
a_host_port = a_host_port
a_login_name = a_login_name


print_d( "\n-------------------- Providing seamless ssh connection --------------------\n" )
from balloon.common import ssh
an_instance2ssh = {}
for an_instance in a_reservation.instances :
    a_host_name = an_instance.public_dns_name
    print_d( 'ssh -o "StrictHostKeyChecking no" -i %s -p %d %s@%s\n' % ( an_identity_file, a_host_port, a_login_name, a_host_name ) )
        
    a_ssh_client = ssh.connect( a_password, an_identity_file, a_host_port, a_login_name, a_host_name )
    a_sftp_client = a_ssh_client.open_sftp()

    import os
    an_upload_name = os.path.basename( an_identity_file )
    a_sftp_client.put( an_identity_file, an_upload_name )

    a_target_name = '${HOME}/.ssh/id_rsa'
    ssh.command( a_ssh_client, 'mv -f %s %s' % ( an_upload_name, a_target_name ) )
    ssh.command( a_ssh_client, 'chmod 600 %s' % ( a_target_name ) )
    ssh.command( a_ssh_client, """sudo sh -c 'echo "    StrictHostKeyChecking no" >> /etc/ssh/ssh_config'""" )

    try :
        a_security_group.authorize( 'tcp', 1, 65535, '%s/0' % an_instance.private_ip_address ) # mpi cluster ports
    except :
        pass

    an_instance2ssh[ an_instance ] = a_ssh_client
    pass

print_d( "\n--- Listing all the cluster nodes into special '.openmpi_hostfile' file ---\n" )
# The suggested cluster conffiguration is symmetric,
# which means that it does not matter who will be the master node.
# (if user need to do something special, he can do it from his own machine)
for a_master_node in a_reservation.instances :
    a_host_name = a_master_node.public_dns_name

    a_ssh_client = an_instance2ssh[ a_master_node ]

    a_number_cpu = ssh.command( a_ssh_client, """python -c 'import os; print os.sysconf( "SC_NPROCESSORS_ONLN" )'""" )[ 0 ][ : -1 ]
    ssh.command( a_ssh_client, 'echo %s slots=%d > .openmpi_hostfile' % ( a_master_node.private_ip_address, int( a_number_cpu ) ) )

    for an_instance in a_reservation.instances :
        if an_instance == a_master_node :
            continue
        ssh.command( a_ssh_client, 'echo %s slots=%d >> .openmpi_hostfile' % ( an_instance.private_ip_address, int( a_number_cpu ) ) )
        pass

    pass

[ a_ssh_client.close() for a_ssh_client in an_instance2ssh.values() ]

print_d( "a_spent_time = %s, sec\n" % a_spent_time )


print_d( "\n------------------ Printing succussive pipeline arguments -----------------\n" )
ec2.use.print_options( *ec2.use.unpack( an_options ) )


print_d( "\n--------------------------- Canonical substitution ------------------------\n" )
print_d( a_call + '\n' )


print_d( "\n-------------------------------------- OK ---------------------------------\n" )



#!/usr/bin/env python

#--------------------------------------------------------------------------------------
## Copyright 2010 Alexey Petrov
##
## Licensed under the Apache License, Version 2.0 (the "License");
## you may not use this file except in compliance with the License.
## You may obtain a copy of the License at
##
##     http://www.apache.org/licenses/LICENSE-2.0
##
## Unless required by applicable law or agreed to in writing, software
## distributed under the License is distributed on an "AS IS" BASIS,
## WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
## See the License for the specific language governing permissions and
## limitations under the License.
##
## See http://sourceforge.net/apps/mediawiki/balloon-foam
##
## Author : Alexey Petrov
##


#--------------------------------------------------------------------------------------
"""
This script upload a file from web and publish it as 'study file' in S3
"""


#--------------------------------------------------------------------------------------
import balloon.common as common
from balloon.common import print_d, print_e, sh_command, Timer
from balloon.common import ssh

from balloon import amazon

import os, os.path


#--------------------------------------------------------------------------------------
# Defining utility command-line interface

an_usage_description = "%prog --remote-location='/mnt'"
an_usage_description += amazon.add_usage_description()
an_usage_description += ssh.add_usage_description()
an_usage_description += common.add_usage_description()

from optparse import IndentedHelpFormatter
a_help_formatter = IndentedHelpFormatter( width = 127 )

from optparse import OptionParser
a_option_parser = OptionParser( usage = an_usage_description, version="%prog 0.1", formatter = a_help_formatter )

a_option_parser.add_option( "--remote-location",
                            metavar = "< destination of the credendtials environemnt files >",
                            action = "store",
                            dest = "remote_location",
                            help = "(\"%default\", by default)",
                            default = "/mnt" )
a_option_parser.add_option( "--aws-user-id",
                            metavar = "< AWS User ID >",
                            action = "store",
                            dest = "aws_user_id",
                            help = "(\"%default\", by default)",
                            default = os.getenv( "AWS_USER_ID" ) )
a_option_parser.add_option( "--ec2-private-key",
                            metavar = "< EC2 Private Key >",
                            action = "store",
                            dest = "ec2_private_key",
                            help = "(\"%default\", by default)",
                            default = os.getenv( "EC2_PRIVATE_KEY" ) )
a_option_parser.add_option( "--ec2-cert",
                            metavar = "<EC2 Certificate >",
                            action = "store",
                            dest = "ec2_cert",
                            help = "(\"%default\", by default)",
                            default = os.getenv( "EC2_CERT" ) )
amazon.add_parser_options( a_option_parser )
ssh.add_parser_options( a_option_parser )
common.add_parser_options( a_option_parser )
  
 
#--------------------------------------------------------------------------------------
# Extracting and verifying command-line arguments

an_options, an_args = a_option_parser.parse_args()

an_enable_debug = common.extract_options( an_options )
AWS_ACCESS_KEY_ID, AWS_SECRET_ACCESS_KEY = amazon.extract_options( an_options )
a_password, an_identity_file, a_host_port, a_login_name, a_host_name, a_command = ssh.extract_options( an_options )

a_remote_location = os.path.abspath( an_options.remote_location )

AWS_USER_ID = an_options.aws_user_id
if AWS_USER_ID == None or AWS_USER_ID == "" :
    a_option_parser.error( "use '--aws-user-id' option to define proper AWS User ID" )
    pass

EC2_PRIVATE_KEY = os.path.abspath( an_options.ec2_private_key )
if not os.path.isfile( EC2_PRIVATE_KEY ) :
    a_option_parser.error( "--ec2-private-key='%s' must be a file" % EC2_PRIVATE_KEY )
    pass

EC2_CERT = os.path.abspath( an_options.ec2_cert )
if not os.path.isfile( EC2_CERT ) :
    a_option_parser.error( "--ec2-cert='%s' must be a file" % EC2_CERT )
    pass

print_d( "\n--------------------------- Canonical substitution ------------------------\n" )
import sys
an_engine = sys.argv[ 0 ]

a_call = "%s --remote-location='%s' %s" % ( an_engine, a_remote_location, ssh.compose_call( an_options ) )

print_d( a_call + '\n' )
ssh.print_call( *ssh.unpack( an_options ) )


print_d( "\n----------------------- Running actual functionality ----------------------\n" )
a_ssh_client = ssh.connect( a_password, an_identity_file, a_host_port, a_login_name, a_host_name )

a_sftp_client = a_ssh_client.open_sftp()
ssh.command( a_ssh_client, 'sudo mkdir --parents %s' % a_remote_location )
ssh.command( a_ssh_client, 'sudo chmod 777 %s' % a_remote_location )
ssh.command( a_ssh_client, 'ls --color=no -alF %s' % a_remote_location )

a_remote_ec2_private_key = os.path.join( a_remote_location, os.path.basename( EC2_PRIVATE_KEY ) )
a_sftp_client.put( EC2_PRIVATE_KEY, a_remote_ec2_private_key )

a_remote_ec2_cert = os.path.join( a_remote_location, os.path.basename( EC2_CERT ) )
a_sftp_client.put( EC2_CERT, a_remote_ec2_cert )

a_remote_rcfile = os.path.join( a_remote_location, ".aws_credentialsrc")
ssh.command( a_ssh_client, 'echo "# AWS Credentials" > %s' % ( a_remote_rcfile ) )
ssh.command( a_ssh_client, 'echo "# ---------------" >> %s' % ( a_remote_rcfile ) )
ssh.command( a_ssh_client, 'echo "export AWS_ACCESS_KEY_ID=%s" >> %s' % ( AWS_ACCESS_KEY_ID, a_remote_rcfile ) )
ssh.command( a_ssh_client, 'echo "export AWS_SECRET_ACCESS_KEY=%s" >> %s' % ( AWS_SECRET_ACCESS_KEY, a_remote_rcfile ) )
ssh.command( a_ssh_client, 'echo "export AWS_USER_ID=%s" >> %s' % ( AWS_USER_ID, a_remote_rcfile ) )
ssh.command( a_ssh_client, 'echo "export EC2_PRIVATE_KEY=%s" >> %s' % ( a_remote_ec2_private_key, a_remote_rcfile ) )
ssh.command( a_ssh_client, 'echo "export EC2_CERT=%s" >> %s' % ( a_remote_ec2_cert, a_remote_rcfile ) )

ssh.command( a_ssh_client, 'source %s && env | grep -E "AWS|EC2"' % ( a_remote_rcfile ) )
ssh.command( a_ssh_client, 'cat %s' % ( a_remote_rcfile ) )

a_ssh_client.close()


print_d( "\n------------------ Printing succussive pipeline arguments -----------------\n" )
ssh.print_options( *ssh.unpack( an_options ) )


print_d( "\n--------------------------- Canonical substitution ------------------------\n" )
ssh.print_call( *ssh.unpack( an_options ) )
print_d( a_call + '\n' )


print_d( "\n-------------------------------------- OK ---------------------------------\n" )

